@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Help;
 
-our $DATE = '2015-04-04'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2015-04-07'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
@@ -97,6 +97,7 @@ sub gen_help {
         push @help, "\nSubcommands:\n";
         if (keys(%$subcommands) >= 12) {
             # comma-separated list
+            no warnings 'once';
             require Text::Wrap;
             local $Text::Wrap::columns = $ENV{COLUMNS} // 80;
             push @help, Text::Wrap::wrap(
@@ -112,6 +113,7 @@ sub gen_help {
 
     # example
     {
+        # XXX categorize too, like options
         last unless @{ $clidocdata->{examples} };
         push @help, "\nExamples:\n";
         my $i = 0;
@@ -143,14 +145,19 @@ sub gen_help {
         last unless keys %$opts;
 
         # find all the categories
-        my %cats; # val=[options...]
+        my %options_by_cat; # val=[options...]
         for (keys %$opts) {
-            push @{ $cats{$opts->{$_}{category}} }, $_;
+            push @{ $options_by_cat{$opts->{$_}{category}} }, $_;
         }
 
-        for my $cat (sort keys %cats) {
+        my $cats_spec = $clidocdata->{option_categories};
+        for my $cat (sort {
+            ($cats_spec->{$a}{order} // 50) <=> ($cats_spec->{$b}{order} // 50)
+                || $a cmp $b }
+                         keys %options_by_cat) {
             # find the longest option
-            my @opts = sort {length($b)<=>length($a)} @{ $cats{$cat} };
+            my @opts = sort {length($b)<=>length($a)}
+                @{ $options_by_cat{$cat} };
             my $len = length($opts[0]);
             # sort again by name
             @opts = sort {
@@ -226,7 +233,7 @@ Perinci::CmdLine::Help - Generate help message for Perinci::CmdLine-based app
 
 =head1 VERSION
 
-This document describes version 0.04 of Perinci::CmdLine::Help (from Perl distribution Perinci-CmdLine-Help), released on 2015-04-04.
+This document describes version 0.05 of Perinci::CmdLine::Help (from Perl distribution Perinci-CmdLine-Help), released on 2015-04-07.
 
 =head1 DESCRIPTION
 
